# senderscore-lookup
Command Line Tool for Lookup at Sender Score.

## Instalation
```shell
pip install senderscore
```

## Usage
```shell
senderscore <IP>
```

More information at www.senderscore.org.
